@@ -5,6 +5,7 @@ pyvitemadose init
 
 from pyvitemadose.args import compute_args
 from pyvitemadose.pyvitemadose import find
+from pyvitemadose.update import update
 
 def pyvitemadose():
     """
@@ -12,5 +13,8 @@ def pyvitemadose():
     """
     args = compute_args()
 
+
+    if args.update:
+        update()
     if args.departement:
         find(args.departement)
